@@ -491,6 +491,12 @@ ImageViewer::createActions()
     slideShowDuration->setAccelerated(true);
     connect(slideShowDuration, SIGNAL(valueChanged(int)), this,
             SLOT(setSlideShowDuration(int)));
+
+    toggleAreaSampleAct = new QAction(tr("&Toggle Area Sample"), this);
+    toggleAreaSampleAct->setCheckable(true);
+    toggleAreaSampleAct->setShortcut(tr("Ctrl+A"));
+    connect(toggleAreaSampleAct, SIGNAL(triggered()), this,
+            SLOT(toggleAreaSample()));
 }
 
 
@@ -737,6 +743,7 @@ ImageViewer::createMenus()
     // Mode: select, zoom, pan, wipe
     toolsMenu->addAction(showInfoWindowAct);
     toolsMenu->addAction(showPixelviewWindowAct);
+    toolsMenu->addAction(toggleAreaSampleAct);
     toolsMenu->addMenu(slideMenu);
     toolsMenu->addMenu(sortMenu);
 
@@ -2387,3 +2394,28 @@ ImageViewer::editPreferences()
     }
     preferenceWindow->show();
 }
+
+
+
+void
+ImageViewer::toggleAreaSample()
+{
+    m_areaSampleMode = !m_areaSampleMode;
+    if (m_areaSampleMode) {
+        setCursor(Qt::CrossCursor);
+    } else {
+        unsetCursor();
+    }
+    // if (m_areaSampleMode == false){
+    //     updateStatusBar();
+    // }
+    ((QOpenGLWidget*)(glwin))->update();
+}
+
+
+
+bool
+ImageViewer::areaSampleMode() const
+{
+    return m_areaSampleMode;
+}
